#%global    tar_version 5.0.4

Name:       openvas-manager
Version:    5.0.6
Release:    2%{?dist}
Summary:    Manager Module for the Open Vulnerability Assessment System (OpenVAS)

License:    GPLv2+
URL:        http://www.openvas.org
Source0:    http://wald.intevation.org/frs/download.php/1730/%{name}-%{version}.tar.gz
#Source0:    http://wald.intevation.org/frs/download.php/1730/%{name}-%{tar_version}.tar.gz
Source1:    openvas-manager.initd
Source2:    openvas-manager.logrotate
Source3:    openvas-manager.sysconfig
Source4:    openvas-manager.service

# Put certs to /etc/pki as suggested by http://fedoraproject.org/wiki/PackagingDrafts/Certificates
# Not reported upstream as it is RedHat/Fedora specific
Patch1:     openvas-manager-pki.patch
Patch2:     openvas-manager-gpgerror.patch

# Replace _BSD_SOURCE and _SVID_SOURCE with _DEFAULT_SOURCE otherwise build fails with Werror
Patch3:		openvas-manager-bsdsource.patch

BuildRequires:	  openvas-libraries-devel >= 7.0
BuildRequires:    cmake >= 2.6.0
BuildRequires:    glib2-devel
BuildRequires:    sqlite-devel
BuildRequires:    gnutls-devel
BuildRequires:    libgcrypt-devel
BuildRequires:    libuuid-devel
BuildRequires:    libpcap-devel
BuildRequires:    libksba-devel
BuildRequires:    gpgme-devel
BuildRequires:    libgpg-error-devel
BuildRequires:    doxygen
BuildRequires:    pkgconfig
BuildRequires:    xmltoman
BuildRequires:    systemd

Requires:   logrotate
Requires:   /usr/bin/xsltproc

Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd

%description
The OpenVAS Manager is the central service that consolidates plain vulnerability
scanning into a full vulnerability management solution. The Manager controls the
Scanner via OTP and itself offers the XML-based, stateless OpenVAS Management 
Protocol (OMP). All intelligence is implemented in the Manager so that it is
possible to implement various lean clients that will behave consistently e.g. 
with regard to filtering or sorting scan results. The Manager also controls 
a SQL database (sqlite-based) where all configuration and scan result data is 
centrally stored.

%package sysvinit
Summary:		SysV style init script for %{name}
Group:			Documentation
Requires:		%{name} = %{version}-%{release}
Requires(post):		chkconfig
Requires(preun):	chkconfig
Requires(preun):	initscripts

%description sysvinit
SysV style init script for %{name}.
It needs to be installed only if systemd is not used as the system init process.

%prep
#%setup -q -n %{name}-%{tar_version}
%setup -q
#%patch0 -p1 -b .notused
%patch1 -p1 -b .pki
%patch2 -p1 -b .gpgerror
%if 0%{?fedora} >= 21
%patch3 -p1 -b .bsdsource
%endif

%build
export CFLAGS="$RPM_OPT_FLAGS -Werror=unused-but-set-variable -lgpg-error"
%cmake -DLOCALSTATEDIR:PATH=%{_var}
make %{?_smp_mflags} VERBOSE=1

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"

# Config directory
mkdir -p %{buildroot}/%{_sysconfdir}/openvas
chmod 755 %{buildroot}/%{_sysconfdir}/openvas

# Log direcotry
mkdir -p %{buildroot}/%{_var}/log/openvas
touch %{buildroot}%{_var}/log/openvas/openvasmd.log

# Runtime lib directory
mkdir -p %{buildroot}/%{_var}/lib/openvas/mgr

# Install startup script
install -Dp -m 755 %{SOURCE1} %{buildroot}/%{_initddir}/%{name}

# Install systemd
install -Dp -m 644 %{SOURCE4} %{buildroot}/%{_unitdir}/%{name}.service

# Install log rotation stuff
install -m 644 -Dp %{SOURCE2} %{buildroot}/%{_sysconfdir}/logrotate.d/%{name}

# Install sysconfig configration
install -Dp -m 644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/sysconfig/%{name}

# Fix permissions on templates
chmod -R a+r %{buildroot}%{_datadir}/openvas/openvasmd
find %{buildroot}%{_datadir}/openvas/openvasmd -name generate | xargs chmod 755

# Clean installed doc directory
rm -rf %{buildroot}%{_datadir}/doc/%{name}

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

%post sysvinit
# This adds the proper /etc/rc*.d links for the script
if [ "$1" -eq 1 ] ; then
	/sbin/chkconfig --add openvas-manager
fi

%preun sysvinit
if [ "$1" -eq 0 ] ; then
	/sbin/service openvas-manager stop >/dev/null 2>&1
	/sbin/chkconfig --del openvas-manager
fi

%postun sysvinit
# only for upgrades not erasure
if [ "$1" -eq 1 ] ; then
	/sbin/service openvas-manager condrestart  >/dev/null 2>&1
fi

%files
# INSTALL file contains post-installation guide for whole openvas
%doc CHANGES COPYING README ChangeLog TODO INSTALL
%doc doc/*.png doc/*.sql doc/*.html doc/report-format-HOWTO doc/about-cert-feed.txt
%doc report_formats
%config(noreplace) %{_sysconfdir}/logrotate.d/openvas-manager
%dir %{_sysconfdir}/openvas
%dir %{_var}/lib/openvas
%dir %{_var}/lib/openvas/mgr
%dir %{_var}/log/openvas
%dir %{_datadir}/openvas
%dir %{_datadir}/openvas/scap
%dir %{_datadir}/openvas/cert
%config(noreplace) %{_sysconfdir}/openvas/openvasmd_log.conf
%config(noreplace) %{_sysconfdir}/openvas/pwpolicy.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_unitdir}/%{name}.service
%{_sbindir}/openvasmd
%{_sbindir}/greenbone-scapdata-sync
%{_sbindir}/greenbone-certdata-sync
%{_sbindir}/openvas-scapdata-sync
%{_sbindir}/openvas-certdata-sync
%{_sbindir}/openvas-portnames-update
%{_mandir}/man8/openvasmd.8*
%{_datadir}/openvas/openvasmd
%{_datadir}/openvas/scap/*
%{_datadir}/openvas/cert/*
%{_datadir}/openvas/openvas-lsc-rpm-creator.sh
%ghost %{_var}/log/openvas/openvasmd.log

%files sysvinit
%{_initrddir}/%{name}

%changelog
* Fri Nov 28 2014 josef radinger <cheese@nosuchhost.net> - 5.0.6-2
- bump version
- resync spec-file

* Fri Nov 07 2014 josef radinger <cheese@nosuchhost.net> - 5.0.5-1
- bump version
- enable nowerror-patch
- modify nowerror-patch

* Tue Sep 09 2014 josef radinger <cheese@nosuchhost.net> - 5.0.4-1
- bump version

* Mon Aug 04 2014 josef radinger <cheese@nosuchhost.net> - 5.0.3-1
- bump version

* Mon Jun 16 2014 josef radinger <cheese@nosuchhost.net> - 5.0.2-1
- bump version

* Thu May 29 2014 josef radinger <cheese@nosuchhost.net> - 5.0.1-18
- bump version

* Mon May 12 2014 Scott R. Shinn <scott@atomicorp.com> - 5.0.1-17
- Update to 5.0.1

* Mon May 5 2014 Scott R. Shinn <scott@atomicorp.com> - 5.0.0-16
- Update to 5.0.0

* Fri Feb 28 2014 Scott R. Shinn <scott@atomicorp.com> - 4.0.5-15
- Update to 4.0.5

* Fri Nov 8 2013 Scott R. Shinn <scott@atomicorp.com> - 4.0.4-14
- Update to 4.0.4

* Fri Oct 25 2013 Scott R. Shinn <scott@atomicorp.com> - 4.0.3-13
- Update to 4.0.3

* Fri Jul 5 2013 Scott R. Shinn <scott@atomicorp.com> - 4.0.2-11
- Update to 4.0.2

* Fri Jun 7 2013 Scott R. Shinn <scott@atomicorp.com> - 4.0.1-10
- Update to 4.0.1

* Thu Apr 18 2013 Scott R. Shinn <scott@atomicorp.com> - 4.0.0-9
- Update to 4.0.0

* Thu Dec 20 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.5-8
- Complete migrate of basic setup into openvas-setup

* Thu Dec 20 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.5-7
- Update to 3.0.5
- Just in time for the apocalypse!

* Mon Dec 3 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.4-6
- Bugfix #XXX, for openvas-scapdata-sync path

* Fri Nov 23 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.4-5
- Bugfix #XXX, for openvas-scapdata-sync path

* Wed Nov 07 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.4-4
- Update to 3.0.4

* Mon Aug 20 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.3-3
- Update to 3.0.3

* Thu May 10 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.1-2
- Update to 3.0.1

* Tue Apr 24 2012 Scott R. Shinn <scott@atomicorp.com> - 3.0.0-1
- Update to 3.0.0

* Tue Jun 14 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0.4-2
- Bugfix #XXX, this changes the keygen code to use DSA instead of RSA to handle a bug in gnutls.

* Wed Jun 1 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0.4-1
- Update to 2.0.4

* Fri May 4 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0.3-3
- Bugfix #XXX, for broken chmod on tasks.db
- Updated openvas-nvt-sync-cron to create the task db if it does not otherwise exist.

* Wed May 4 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0.3-2
- Minor %post update to create the task.db before --rebuild runs

* Fri Apr 15 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0.3-1
- UPdate to 2.0.3

* Tue Feb 22 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0.1-1
- Update to 2.0.1

* Thu Feb 17 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0.0-1
- Update to 2.0.0 final

* Wed Jan 19 2011 Scott R. Shinn <scott@atomicorp.com> - 2.0-0.3
- Update to 2.0 rc2

* Thu Dec 30 2010 Scott R. Shinn <scott@atomicorp.com> - 2.0-0.2
- Update 2.0 rc1

* Fri Dec 10 2010 Scott R. Shinn <scott@atomicorp.com> - 2.0-0.1
- Update to 2.0 beta 3

* Mon Aug 30 2010 Scott R. Shinn <scott@atomicorp.com> - 1.0.2-2
- Added init script
- Added sysconfig
- Added Logrotate
- Added %post/%postun macros to configure/create users and databases
- Added %post routine to reconfigure openvas-scanner to work with manager

* Thu Aug 26 2010 Scott R. Shinn <scott@atomicorp.com> - 1.0.2-1
- Update to 1.0.2

* Thu Jul 29 2010 Scott R. Shinn <scott@atomicorp.com> - 1.0.0-1
- Update to 1.0.0 final

* Wed Apr 28 2010 Scott R. Shinn <scott@atomicorp.com> - 1.0.0-beta6.1-1
- Update to beta6

* Tue Apr 13 2010 Scott R. Shinn <scott@atomicorp.com> - 1.0.0-beta5.1-1
- initial build
